Module scale_decode::visitor
source · Expand description
The Visitor trait and associated types.
Modules
- Types used in the
super::Visitortrait definition.
Structs
- A
Visitorimplementation that just ignores all of the bytes. - The ID of the type being decoded.
- Some
Visitorimplementations may want to return an error type other thancrate::Error, which means that they would not be automatically compatible withcrate::IntoVisitor, which requires visitors that do returncrate::Errorerrors.
Enums
- The response from
Visitor::unchecked_decode_as_type(). - An error decoding SCALE bytes.
- This is returned by default when a visitor function isn’t implemented.
Traits
- This is implemented for visitor related types which have a
decode_itemmethod, and allows you to generically talk about decoding unnamed items. - An implementation of the
Visitortrait can be passed to thedecode_with_visitor()function, and is handed back values as they are encountered. It’s up to the implementation to decide what to do with these values.
Functions
- Decode data according to the type ID and
PortableRegistryprovided. The provided pointer to the data slice will be moved forwards as needed depending on what was decoded, and a method on the providedVisitorwill be called depending on the type that needs to be decoded.
Type Aliases
- An error that can occur trying to decode a bit sequence.