Module scale_decode::visitor::types

source ·
Types used in the super::Visitor trait definition.

Structs

  • This enables a visitor to decode items from an array type.
  • This represents a BitSequence, deferring decoding until the implementation wants to.
  • This represents a composite type.
  • This enables a visitor to decode items from a sequence type.
  • This represents a string, but defers proper decoding of it until it’s asked for, and avoids allocating.
  • This represents a tuple of values.
  • A representation of the a variant type.